==> dde-file-manager_5.2.18.orig.tar.xz: dde-file-manager-5.2.18/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_zh_HK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_HK" version="2.1">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>認證超時</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>磁盤文件被佔用，無法卸載</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>磁盤文件被佔用，無法彈出</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>光驅正忙，無法彈出</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>設備正忙，無法安全移除</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>%1 卷</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>未知</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>設備沒有正常移除</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>請點擊“安全移除”後，再斷開連接</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation type="vanished">光驅正忙，無法彈出</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation type="vanished">設備正忙，無法安全移除</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>無法卸載設備</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>磁盤由用戶“%1”掛載，您沒有卸載權限。</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>找不到對應的掛載設備</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>磁盤列表</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>磁盤</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>打開</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>全部彈出</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>設備已被安全移除</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>禁止訪問</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>您沒有權限讀取此文件夾</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>確定</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>正在掃描當前設備，是否終止掃描？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>終止</translation>
    </message>
</context>
</TS>

==> dde-file-manager_5.9.2.orig.tar.xz: dde-file-manager-5.9.2/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_zh_HK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_HK">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>認證超時</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>磁盤文件被佔用，無法卸載</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>磁盤文件被佔用，無法彈出</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>光驅正忙，無法彈出</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>設備正忙，無法安全移除</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>%1 卷</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>未知</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>設備沒有正常移除</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>請點擊“安全移除”後，再斷開連接</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>無法卸載設備</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>磁盤由用戶“%1”掛載，您沒有卸載權限。</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>找不到對應的掛載設備</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>磁盤列表</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>磁盤</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>打開</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>全部彈出</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>設備已被安全移除</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>禁止訪問</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>您沒有權限讀取此文件夾</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>正在掃描當前設備，是否終止掃描？</translation>
    </message>
    <message>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>確 定</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Stop</source>
        <comment>button</comment>
        <translation>終 止</translation>
    </message>
</context>
</TS>
